import matplotlib.pyplot as plt
import pandas as pd
from plot import set_rc, save_plot
from plot_fidelity import set_ax, plot_fidelity

df_pmem_bi = pd.read_csv("data/p_mem/bipartite.csv")
df_pmem_fac = pd.read_csv("data/p_mem/factory.csv")
df_qbsm_bi = pd.read_csv("data/q_bsm/bipartite.csv")
df_qbsm_fac = pd.read_csv("data/q_bsm/factory.csv")
df_n_bi = pd.read_csv("data/N/bipartite.csv")
df_n_bi = df_n_bi[df_n_bi["num_remote_nodes"] <= 8]  # to account for factory data only available up until N = 8
df_n_fac = pd.read_csv("data/N/factory.csv")

set_rc()
fig, axs = plt.subplots(3, figsize=(5, 10), sharey=False)

set_ax(df_pmem_bi, axs[0])
set_ax(df_qbsm_bi, axs[1])
set_ax(df_n_bi, axs[2])

plot_fidelity(dataframe=df_pmem_bi, name="2-switch", ax=axs[0])
plot_fidelity(dataframe=df_pmem_fac, name="Factory", ax=axs[0])
axs[0].ticklabel_format(style="sci", scilimits=(-2, 2))
axs[0].set_xticks([0.00025 * i for i in range(5)])
axs[0].set_yticks([0.4 + 0.2 * i for i in range(4)])
plot_fidelity(dataframe=df_qbsm_bi, name="2-switch", ax=axs[1])
plot_fidelity(dataframe=df_qbsm_fac, name="Factory", ax=axs[1])
axs[1].set_xticks([0.5, 0.75, 1])
axs[1].set_yticks([0.86, 0.88, 0.90, 0.92])
plot_fidelity(dataframe=df_n_bi, name="2-switch", ax=axs[2])
plot_fidelity(dataframe=df_n_fac, name="Factory", ax=axs[2])
axs[2].set_xticks(list(range(3, 8, 2)))
axs[2].set_yticks([0.7, 0.8, 0.9, 1])
fig.tight_layout()
axs[0].legend()
save_plot("comparison_fidelities_pmem.png")
