import matplotlib.pyplot as plt
import pandas as pd
from plot_rate import plot_rate
from plot import set_rc, save_plot
from plot_rate import set_ax

df_qlink_bi = pd.read_csv("data/q_link/small_range/bipartite.csv")
df_qlink_fac = pd.read_csv("data/q_link/small_range/factory.csv")
df_n_bi = pd.read_csv("data/N/bipartite.csv")
df_n_bi = df_n_bi[df_n_bi["num_remote_nodes"] <= 8]  # to account for factory data only available up until N = 8
df_n_fac = pd.read_csv("data/N/factory.csv")
df_qbsm_bi = pd.read_csv("data/q_bsm/bipartite.csv")
df_qbsm_fac = pd.read_csv("data/q_bsm/factory.csv")

set_rc()
fig, axs = plt.subplots(3, figsize=(5, 10), sharey=False)

set_ax(df_qlink_bi, axs[0])
set_ax(df_qbsm_bi, axs[1])
set_ax(df_n_bi, axs[2])

plot_rate(dataframe=df_qlink_bi, name="2-switch", ax=axs[0])
plot_rate(dataframe=df_qlink_fac, name="Factory", ax=axs[0])
axs[0].set_xticks([0, 0.01, 0.02])
axs[0].set_yticks([0, 0.005, 0.01])
plot_rate(dataframe=df_qbsm_bi, name="2-switch", ax=axs[1])
plot_rate(dataframe=df_qbsm_fac, name="Factory", ax=axs[1])
axs[1].set_xticks([0.5, 0.75, 1])
plot_rate(dataframe=df_n_bi, name="2-switch", ax=axs[2])
plot_rate(dataframe=df_n_fac, name="Factory", ax=axs[2])
axs[2].set_yticks([0.003, 0.004, 0.005])
axs[2].set_xticks(list(range(3, 8, 2)))

for ax in axs:
    ax.ticklabel_format(style="sci", scilimits=(-2, 2))

fig.tight_layout()
axs[0].legend()
axs[0].set_ylim(bottom=0)
axs[1].set_ylim(bottom=0)
save_plot("comparison_rate.png")
