import matplotlib.pyplot as plt
import pandas as pd
from plot import save_plot
from plot_fidelity import set_ax, plot_factory_fidelity_estimate, plot_factory_fidelity_bound, plot_max_mixed_line, \
    plot_fidelity

df_large_range = pd.read_csv("data/q_link/verification/factory_large_range.csv")
df_small_range = pd.read_csv("data/q_link/verification/factory_small_range.csv")

plt.rcParams.update({
    "font.size": 12,
})
fig, axs = plt.subplots(1, 2, figsize=(10, 4))

set_ax(df_large_range, axs[0])
set_ax(df_small_range, axs[1])

plot_fidelity(dataframe=df_large_range, name="Simulation", ax=axs[0])
plot_factory_fidelity_estimate(dataframe=df_large_range, name="Leading Order", ax=axs[0])
plot_factory_fidelity_bound(df_large_range, name="Lower Bound", ax=axs[0])
plot_max_mixed_line(df_large_range, ax=axs[0])
axs[0].set_ylim(bottom=0)
axs[0].ticklabel_format(style="sci", scilimits=(-2, 2))

plot_fidelity(dataframe=df_small_range, name="Simulation", ax=axs[1])
plot_factory_fidelity_estimate(dataframe=df_small_range, name="Leading Order", ax=axs[1])
plot_factory_fidelity_bound(df_small_range, name="Lower Bound", ax=axs[1])
axs[1].set_ylim(bottom=0.4)

fig.tight_layout()

for ax in axs:
    ax.set_xlim(left=0)
axs[0].legend()
axs[0].ticklabel_format(style="sci", scilimits=(-2, 2))
save_plot("verification_fidelity_qlink.png")
